@@ -17,7 +17,7 @@ This script shows you example how you can use C<get_logger()>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2008 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -26,7 +26,7 @@ modify it under the same terms as Perl itself.
 
 use strict;
 use warnings;
-use Log::Handler 'myapp' => 'LOG';
+use Log::Handler myapp => 'LOG';
 use lib '.';
 use MyApp;
 
